@@ -22,6 +22,7 @@ class Action(Enum):
     APPROVED = 'approved'
     CLOSE = 'close'
     REOPEN = 'reopen'
+    UNAPPROVED = 'unapproved'
 
 
 @dataclass
@@ -151,9 +152,9 @@ class MergeRequestEvent:
                 )
             )
         elif self.action == Action.APPROVED:
-            text = f'{self.short_link} *approved* by {self.event_author}.'
+            text = f'{self.short_link} *approved* by {self.event_author}'
         elif self.action == Action.MERGE:
-            text = f'{self.short_link} *merged* by {self.event_author}.'
+            text = f'{self.short_link} *merged* by {self.event_author}'
         elif self.action == Action.UPDATE:
             assert isinstance(self.assignees_change, AssigneesChange)
             current_assignees = format_users(
@@ -164,8 +165,10 @@ class MergeRequestEvent:
             else:
                 text = f'{self.short_link} *reassigned* to {current_assignees}'
         elif self.action == Action.CLOSE:
-            text = f'{self.short_link} *closed* by {self.event_author}.'
+            text = f'{self.short_link} *closed* by {self.event_author}'
         elif self.action == Action.REOPEN:
-            text = f'{self.short_link} *reopened* by {self.event_author}.'
+            text = f'{self.short_link} *reopened* by {self.event_author}'
+        elif self.action == Action.UNAPPROVED:
+            text = f'{self.short_link} *unapproved* by {self.event_author}'
 
         return Message(text=text, thread_key=self.mr_id)
